@@ -720,6 +720,10 @@ S3SettingsTypeDef = TypedDict(
             "YYYYMMDD", "YYYYMMDDHH", "YYYYMM", "MMYYYYDD", "DDMMYYYY"
         ],
         "DatePartitionDelimiter": Literal["SLASH", "UNDERSCORE", "DASH", "NONE"],
+        "UseCsvNoSupValue": bool,
+        "CsvNoSupValue": str,
+        "PreserveTransactions": bool,
+        "CdcPath": str,
     },
     total=False,
 )
